==> FRB-1.1.1.tar.gz: FRB-1.1.1/setup.py <==
# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

VERSION = (1, 1, 1)
__version__ = VERSION
__versionstr__ = '.'.join(map(str, VERSION))

# Get the long description from the README file
with open(path.join(here, 'docs/index.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='FRB',
    version=__versionstr__,

    description='Federal Reserve Economic Data (FRED)',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/avelkoski/FRB',
    download_url='https://github.com/avelkoski/FRB/archive/master.zip',

    # Author details
    author='Aleksandar Velkoski',
    author_email='avelkoski@ltu.edu',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    # What does your project relate to?
    keywords='macroeconomics microeconomics finance fred alfred api federal reserve bank economics data',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=['pandas'],
)

==> FRB-1.1.2.tar.gz: FRB-1.1.2/setup.py <==
# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

VERSION = (1, 1, 2)
__version__ = VERSION
__versionstr__ = '.'.join(map(str, VERSION))

# Get the long description from the README file
with open(path.join(here, 'docs/index.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='FRB',
    version=__versionstr__,

    description='Federal Reserve Economic Data (FRED)',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/avelkoski/FRB',
    download_url='https://github.com/avelkoski/FRB/archive/master.zip',

    # Author details
    author='Aleksandar Velkoski',
    author_email='avelkoski@ltu.edu',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    # What does your project relate to?
    keywords='macroeconomics microeconomics finance fred alfred api federal reserve bank economics data',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=['pandas'],
)
